==> bcc-core-api-node-sdk-1.11.0.tgz: package/lib/esm/api/personsClient.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { GenericClient } from "./genericClient.js";
export class PersonsClient {
    constructor(basePath, auth, queryOptions) {
        this.client = new GenericClient({
            basePath: basePath,
            endpointPath: "/v2/persons",
            auth: auth,
            writeTypeName: "PersonWrite",
            singleResponseTypeName: "WrappedPerson",
            multipleResponseTypeName: "WrappedWithMetaArrayPerson",
            patchTypeName: "PersonWritePatch",
            queryOptions: queryOptions,
        });
    }
    create(person) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.create(person);
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.remove(id);
        });
    }
    get(id, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.get(id, query);
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.find(findParams);
        });
    }
    patch(id, person) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.patch(id, person);
        });
    }
}

==> bcc-core-api-node-sdk-1.14.1.tgz: package/lib/esm/api/personsClient.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { GenericClient } from "./genericClient.js";
export class PersonsClient {
    constructor(basePath, auth, queryOptions) {
        this.client = new GenericClient({
            basePath: basePath,
            endpointPath: "/v2/persons",
            auth: auth,
            writeTypeName: "PersonWrite",
            singleResponseTypeName: "WrappedPerson",
            multipleResponseTypeName: "WrappedWithMetaArrayPerson",
            queryOptions: queryOptions,
        });
    }
    create(person) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.create(person);
        });
    }
    remove(id) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.remove(id);
        });
    }
    get(id, query = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.get(id, query);
        });
    }
    find(findParams = {}) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.find(findParams);
        });
    }
    update(id, person) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.client.update(id, person);
        });
    }
}
